package com.zoloz.react;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.ap.zoloz.hummer.api.IZLZCallback;
import com.ap.zoloz.hummer.api.ZLZConstants;
import com.ap.zoloz.hummer.api.ZLZFacade;
import com.ap.zoloz.hummer.api.ZLZRequest;
import com.ap.zoloz.hummer.api.ZLZResponse;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.module.annotations.ReactModule;

import java.util.HashMap;
import java.util.Map;

@ReactModule(name = ZolozkitModule.NAME)
public class ZolozkitModule extends ReactContextBaseJavaModule {
    public static final String NAME = "ZolozKit";

    public ZolozkitModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @NonNull
    @Override
    public String getName() {
        return NAME;
    }

    @ReactMethod
    public void start(String clientCfg, ReadableMap bizConfig, Callback callback) {
        ZLZRequest request = new ZLZRequest();
        request.bizConfig = new HashMap<>();
        request.bizConfig.put(ZLZConstants.CONTEXT, getCurrentActivity());
        request.bizConfig.putAll(bizConfig.toHashMap());
        request.zlzConfig = clientCfg;
        ZLZFacade.getInstance().start(request, new IZLZCallback() {
            @Override
            public void onCompleted(ZLZResponse zlzResponse) {
                callback.invoke(true);
            }

            @Override
            public void onInterrupted(ZLZResponse zlzResponse) {
                callback.invoke(false);
            }
        });
    }

    @ReactMethod
    public void getMetaInfo(Callback callback) {
        callback.invoke(ZLZFacade.getMetaInfo(getCurrentActivity()));
    }

    @Nullable
    @Override
    public Map<String, Object> getConstants() {
        Map<String, Object> constants = new HashMap<>();
        constants.put("ZLZ_LOCAL_KEY", ZLZConstants.LOCALE);
        constants.put("ZLZ_CHAMELEON_KEY", ZLZConstants.CHAMELEON_CONFIG_PATH);
        constants.put("ZLZ_PUB_KEY", ZLZConstants.PUBLIC_KEY);
        return constants;
    }
}
