#import "ZolozKitModule.h"
#import <hummer/ZLZFacade.h>
#import <hummer/ZLZRequest.h>
#import <hummer/ZLZResponse.h>
#import <hummer/ZLZHummerFacade.h>

@protocol ZolozkitForPluginViewControllerDelegate
- (void)onResult:(BOOL)isSuccess withResponse:(ZLZResponse *)response;
@end

@interface ZolozkitForPluginViewController : UIViewController
@property(nonatomic, strong) NSString *clientCfg;
@property(nonatomic, strong) NSDictionary *bizCfg;
@property(nullable, nonatomic, weak) id <ZolozkitForPluginViewControllerDelegate> delegate;
@end

@implementation ZolozkitForPluginViewController
- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
}


- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor clearColor];
    [self.navigationController.navigationBar setBackgroundImage:[[UIImage alloc] init] forBarMetrics:UIBarMetricsDefault];
    self.navigationController.navigationBar.shadowImage = [[UIImage alloc] init];
    self.navigationController.navigationBar.translucent = YES;
    self.navigationController.view.backgroundColor = [UIColor clearColor];
    [self startZoloz];
}

- (void)startZoloz {
    NSString *clientCfg = self.clientCfg;
    if (!self.bizCfg) {
      self.bizCfg = @{};
    }
    NSDictionary *bizCfg = self.bizCfg;
    NSMutableDictionary *bizConfig = [[NSMutableDictionary alloc] initWithDictionary:bizCfg];
    [bizConfig setObject:self forKey:kZLZCurrentViewControllerKey];
    ZLZRequest *request = [[ZLZRequest alloc] initWithzlzConfig:clientCfg bizConfig:bizConfig];
    __weak typeof(self) weakSelf = self;
    [[ZLZFacade sharedInstance]
            startWithRequest:request
            completeCallback:^(ZLZResponse *response) {
                dispatch_async(dispatch_get_main_queue(), ^{
                    [weakSelf dismissViewControllerAnimated:NO completion:^{
                        [weakSelf onResult:YES withResponse:response];
                    }];
                });
            }
           interruptCallback:^(ZLZResponse *response) {
               dispatch_async(dispatch_get_main_queue(), ^{
                   [weakSelf dismissViewControllerAnimated:NO completion:^{
                       [weakSelf onResult:NO withResponse:response];
                   }];
               });
           }];
}

- (void)onResult:(BOOL)isSuccess withResponse:(ZLZResponse *)response {
    NSLog(@"onResult called");
    [self.delegate onResult:isSuccess withResponse:response];
}

@end

@interface ZolozKitModule()<ZolozkitForPluginViewControllerDelegate>
@property(nonatomic, strong) RCTResponseSenderBlock callback;
@end

@implementation ZolozKitModule
RCT_EXPORT_MODULE(ZolozKit);
RCT_EXPORT_METHOD(start:(NSString *)clientCfg bizConfig:(NSDictionary *)bizCfg callback:(RCTResponseSenderBlock)cb)
{
  self.callback = cb;
  dispatch_async(dispatch_get_main_queue(), ^{
    UIViewController *rootViewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
    ZolozkitForPluginViewController *viewController = [[ZolozkitForPluginViewController alloc] init];
    viewController.clientCfg = clientCfg;
    viewController.bizCfg = bizCfg;
    viewController.delegate = self;
    UINavigationController *navigationController = [[UINavigationController alloc] initWithRootViewController:viewController];
    navigationController.modalPresentationStyle = UIModalPresentationOverFullScreen;
    [rootViewController presentViewController:navigationController animated:NO completion:nil];
  });
  
}

RCT_EXPORT_METHOD(getMetaInfo:(RCTResponseSenderBlock)cb) {
  cb(@[[ZLZFacade getMetaInfo]]);
}

- (void)onResult:(BOOL)isSuccess withResponse:(ZLZResponse *)response {
  self.callback(@[@(isSuccess)]);
  self.callback =  nil;
}


- (NSDictionary *)constantsToExport {
    return @{@"ZLZ_LOCAL_KEY": kZLZLocaleKey,
             @"ZLZ_CHAMELEON_KEY": kZLZChameleonConfigKey,
             @"ZLZ_PUB_KEY": kZLZPubkey
    };
}
+(BOOL) requiresMainQueueSetup {
  return YES;
}
@end
